@@ -40,8 +40,6 @@ pub mod error_detail;
 pub use self::error_detail::ErrorDetail;
 pub mod event_source;
 pub use self::event_source::EventSource;
-pub mod event_type_f42_enum;
-pub use self::event_type_f42_enum::EventTypeF42Enum;
 pub mod experiment;
 pub use self::experiment::Experiment;
 pub mod experiment_device_config;
@@ -206,8 +204,8 @@ pub mod patched_user_request;
 pub use self::patched_user_request::PatchedUserRequest;
 pub mod polymorphic_event;
 pub use self::polymorphic_event::PolymorphicEvent;
-pub mod polymorphic_event_create_request;
-pub use self::polymorphic_event_create_request::PolymorphicEventCreateRequest;
+pub mod polymorphic_event_request;
+pub use self::polymorphic_event_request::PolymorphicEventRequest;
 pub mod print_job_event;
 pub use self::print_job_event::PrintJobEvent;
 pub mod print_job_event_request;
@@ -258,8 +256,8 @@ pub mod telemetry_event_request;
 pub use self::telemetry_event_request::TelemetryEventRequest;
 pub mod test_event;
 pub use self::test_event::TestEvent;
-pub mod test_event_event_type_enum;
-pub use self::test_event_event_type_enum::TestEventEventTypeEnum;
+pub mod test_event_model;
+pub use self::test_event_model::TestEventModel;
 pub mod test_event_name;
 pub use self::test_event_name::TestEventName;
 pub mod test_event_request;
@@ -272,7 +270,9 @@ pub mod user_request;
 pub use self::user_request::UserRequest;
 pub mod web_rtc_event;
 pub use self::web_rtc_event::WebRtcEvent;
-pub mod web_rtc_event_create_request;
-pub use self::web_rtc_event_create_request::WebRtcEventCreateRequest;
+pub mod web_rtc_event_model;
+pub use self::web_rtc_event_model::WebRtcEventModel;
 pub mod web_rtc_event_name;
 pub use self::web_rtc_event_name::WebRtcEventName;
+pub mod web_rtc_event_request;
+pub use self::web_rtc_event_request::WebRtcEventRequest;
